==> developer-center-api-3.5.50-20200602.093020-4-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/StrategyCaseQuery.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import java.io.Serializable;

/**
 * 〈功能概述〉<br>
 *
 * @author: xuwei
 * @date: 2020/5/27
 */
public class StrategyCaseQuery implements Serializable {

    private static final long serialVersionUID = -1599926277965154102L;

    /**
     * 案例名称
     */
    private String name;

    /**
     * 行业
     */
    private Integer industry;
    /**
     * 行业类型
     */
    private Integer industryType;
    /**
     * 客户名称
     */
    private String customer;
    /**
     * 经营指标
     */
    private Integer indicator;
    /**
     * 有效性
     */
    private Integer validation;
    /**
     * 玩法类型
     */
    private Integer playwayType;
    /**
     * 玩法名称
     */
    private String playwayName;
    /**
     * 组件
     */
    private Integer playwayModule;
    /**
     * 面向用户
     */
    private Integer userType;
    /**
     * 用户场景
     */
    private String userScenario;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getIndustry() {
        return industry;
    }

    public void setIndustry(Integer industry) {
        this.industry = industry;
    }

    public Integer getIndustryType() {
        return industryType;
    }

    public void setIndustryType(Integer industryType) {
        this.industryType = industryType;
    }

    public String getCustomer() {
        return customer;
    }

    public void setCustomer(String customer) {
        this.customer = customer;
    }

    public Integer getIndicator() {
        return indicator;
    }

    public void setIndicator(Integer indicator) {
        this.indicator = indicator;
    }

    public Integer getValidation() {
        return validation;
    }

    public void setValidation(Integer validation) {
        this.validation = validation;
    }

    public Integer getPlaywayType() {
        return playwayType;
    }

    public void setPlaywayType(Integer playwayType) {
        this.playwayType = playwayType;
    }

    public String getPlaywayName() {
        return playwayName;
    }

    public void setPlaywayName(String playwayName) {
        this.playwayName = playwayName;
    }

    public Integer getPlaywayModule() {
        return playwayModule;
    }

    public void setPlaywayModule(Integer playwayModule) {
        this.playwayModule = playwayModule;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public String getUserScenario() {
        return userScenario;
    }

    public void setUserScenario(String userScenario) {
        this.userScenario = userScenario;
    }
}

==> developer-center-api-3.5.60-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/StrategyCaseQuery.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import java.io.Serializable;

/**
 * 〈功能概述〉<br>
 *
 * @author: xuwei
 * @date: 2020/5/27
 */
public class StrategyCaseQuery implements Serializable {

    private static final long serialVersionUID = -1599926277965154102L;

    /**
     * 案例名称
     */
    private String name;

    /**
     * 行业
     */
    private Long industry;
    /**
     * 行业类型
     */
    private Long industryType;
    /**
     * 客户名称
     */
    private String customer;
    /**
     * 经营指标
     */
    private Long indicator;
    /**
     * 有效性
     */
    private Integer validation;
    /**
     * 玩法类型
     */
    private Long playwayType;
    /**
     * 玩法名称
     */
    private String playwayName;
    /**
     * 组件
     */
    private Long playwayModule;
    /**
     * 面向用户
     */
    private Long userType;
    /**
     * 用户场景
     */
    private String userScenario;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getIndustry() {
        return industry;
    }

    public void setIndustry(Long industry) {
        this.industry = industry;
    }

    public Long getIndustryType() {
        return industryType;
    }

    public void setIndustryType(Long industryType) {
        this.industryType = industryType;
    }

    public String getCustomer() {
        return customer;
    }

    public void setCustomer(String customer) {
        this.customer = customer;
    }

    public Long getIndicator() {
        return indicator;
    }

    public void setIndicator(Long indicator) {
        this.indicator = indicator;
    }

    public Integer getValidation() {
        return validation;
    }

    public void setValidation(Integer validation) {
        this.validation = validation;
    }

    public Long getPlaywayType() {
        return playwayType;
    }

    public void setPlaywayType(Long playwayType) {
        this.playwayType = playwayType;
    }

    public String getPlaywayName() {
        return playwayName;
    }

    public void setPlaywayName(String playwayName) {
        this.playwayName = playwayName;
    }

    public Long getPlaywayModule() {
        return playwayModule;
    }

    public void setPlaywayModule(Long playwayModule) {
        this.playwayModule = playwayModule;
    }

    public Long getUserType() {
        return userType;
    }

    public void setUserType(Long userType) {
        this.userType = userType;
    }

    public String getUserScenario() {
        return userScenario;
    }

    public void setUserScenario(String userScenario) {
        this.userScenario = userScenario;
    }
}
